@@ -27,7 +27,7 @@ def GetAzureMLRun():
 def RegisterModel(model_path, description, args):
     run = GetAzureMLRun()
 
-    if run:
+    if run and run is not None:
         experiment = Run.get_context(allow_offline=False).experiment
         ws = experiment.workspace
 
@@ -52,7 +52,7 @@ def RegisterModel(model_path, description, args):
     
 def DownloadModel(model_id, model_path):
     run = GetAzureMLRun()
-    if run:
+    if run and run is not None:
         experiment = Run.get_context(allow_offline=False).experiment
         ws = experiment.workspace
         model = Model(ws, model_id)
@@ -129,7 +129,7 @@ def DeployModel():
     run = GetAzureMLRun()
 
     ## If it is running in AML context
-    if run:
+    if run and run is not None:
         experiment = Run.get_context(allow_offline=False).experiment
         ws = experiment.workspace
         model = Model(ws, model_id)
